import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { Button, Text } from '@primer/react';
import { useState } from 'react';
import { createRoot } from 'react-dom/client';
import { Output } from '../components/output/Output';
import { useOutputsStore } from '../components/output/OutputState';
import { Jupyter } from '../jupyter/Jupyter';
import { useJupyter } from '../jupyter/JupyterContext';
import { ExecutionPhase } from '../jupyter/kernel/KernelState';
const SOURCE_ID_1 = 'output-id-1';
const SOURCE_1 = 'fail';
const SOURCE_ID_2 = 'output-id-2';
const SOURCE_2 = '2+2';
const OUTPUTS_2 = [
    {
        data: {
            'text/plain': ['4'],
        },
        execution_count: 1,
        metadata: {},
        output_type: 'execute_result',
    },
];
const SOURCE_ID_3 = 'output-id-3';
const SOURCE_3 = 'a = 5';
const SOURCE_ID_4 = 'output-id-4';
const SOURCE_4 = "import warnings; warnings.warn('This is a warning message'); print('See warning in output!')";
const SOURCE_ID_5 = 'output-id-5';
const SOURCE_5 = 'print(2+2)';
const OutputWithMonitoring = ({ title, id, code, output, }) => {
    const { defaultKernel } = useJupyter();
    const outputStore = useOutputsStore();
    const [execTrigger, setExecTrigger] = useState(0);
    const [executionLog, setExecutionLog] = useState([]);
    console.log('Outputs', outputStore.getModel(id)?.toJSON(), outputStore.getInput(id));
    const handleExecutionPhaseChanged = (phaseOutput) => {
        switch (phaseOutput.executionPhase) {
            case ExecutionPhase.running:
                const log = [new Date().toISOString() + ' EXECUTION PHASE - RUNNING'];
                setExecutionLog(log);
                break;
            case ExecutionPhase.completed:
                setExecutionLog(executionLog => [
                    ...executionLog,
                    new Date().toISOString() +
                        ' EXECUTION PHASE - COMPLETED and output ' +
                        JSON.stringify(phaseOutput.outputModel?.toJSON()),
                ]);
                break;
            case ExecutionPhase.completed_with_error:
                setExecutionLog(executionLog => [
                    ...executionLog,
                    new Date().toISOString() +
                        ' EXECUTION PHASE - COMPLETED_WITH_ERROR and output ' +
                        JSON.stringify(phaseOutput.outputModel?.toJSON()),
                ]);
                break;
            case ExecutionPhase.completed_with_warning:
                setExecutionLog(executionLog => [
                    ...executionLog,
                    new Date().toISOString() +
                        ' EXECUTION PHASE - COMPLETED_WITH_WARNING and output ' +
                        JSON.stringify(phaseOutput.outputModel?.toJSON()),
                ]);
                break;
        }
    };
    return (_jsxs(_Fragment, { children: [_jsx(Text, { as: "h1", children: title }), _jsx(Button, { onClick: () => setExecTrigger(execTrigger => execTrigger + 1), children: "Execute with monitoring" }), _jsxs("div", { style: {
                    padding: '10px',
                    width: '100%',
                    display: 'flex',
                    flexDirection: 'column',
                }, children: [_jsx("span", { style: { fontWeight: '600' }, children: "Execution log" }), _jsx("div", { children: executionLog.map((logEntry, index) => {
                            return (_jsx("p", { style: { textAlign: 'left' }, children: logEntry }, index));
                        }) })] }), _jsx(Output, { autoRun: false, code: code, id: id, kernel: defaultKernel, executeTrigger: execTrigger, outputs: output ? output : [], onExecutionPhaseChanged: handleExecutionPhaseChanged, suppressCodeExecutionErrors: true, showEditor: true })] }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsxs(Jupyter, { children: [_jsx(OutputWithMonitoring, { title: "Output with error code", id: SOURCE_ID_1, code: SOURCE_1 }, "1"), _jsx(OutputWithMonitoring, { title: "Output with correct code", id: SOURCE_ID_2, code: SOURCE_2, output: OUTPUTS_2 }, "2"), _jsx(OutputWithMonitoring, { title: "Code with no output", id: SOURCE_ID_3, code: SOURCE_3 }, "3"), _jsx(OutputWithMonitoring, { title: "Code generating warning", id: SOURCE_ID_4, code: SOURCE_4 }, "4"), _jsx(OutputWithMonitoring, { title: "Code with stream output", id: SOURCE_ID_5, code: SOURCE_5 }, "5")] }));
//# sourceMappingURL=OutputWithMonitoring.js.map