import { Builder, Contents, Event, IManager, NbConvert, NbConvertManager, ServerConnection, ServiceManager, Setting, User, Workspace, SettingManager, WorkspaceManager } from '@jupyterlab/services';
import { BuildManager } from '@jupyterlab/services/lib/builder';
import { IKernelConnection, IManager as IKernelManager, IModel } from '@jupyterlab/services/lib/kernel/kernel';
import { IManager as IKernelspecManager, ISpecModels } from '@jupyterlab/services/lib/kernelspec/kernelspec';
import { IModel as ISessionModel, ISessionConnection, IManager as ISessionManager, ISessionOptions } from '@jupyterlab/services/lib/session/session';
import { IModel as ITerminalModel, IManager as ITerminaManager, ITerminal, ITerminalConnection } from '@jupyterlab/services/lib/terminal/terminal';
import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { PromiseDelegate, ReadonlyJSONObject } from '@lumino/coreutils';
import { ISignal } from '@lumino/signaling';
export declare class TerminalManagerLess implements ITerminaManager {
    runningChanged: ISignal<ITerminaManager, ITerminalModel[]>;
    connectionFailure: ISignal<ITerminaManager, ServerConnection.NetworkError>;
    isReady: boolean;
    ready: Promise<void>;
    serverSettings: ServerConnection.ISettings;
    isActive: boolean;
    disposed: ISignal<this, void>;
    isDisposed: boolean;
    constructor(serverSettings: ServerConnection.ISettings);
    isAvailable(): boolean;
    running(): IterableIterator<ISessionModel>;
    startNew(options?: ITerminal.IOptions | undefined): Promise<ITerminalConnection>;
    connectTo(options: Omit<ITerminalConnection.IOptions, 'serverSettings'>): ITerminalConnection;
    shutdown(name: string): Promise<void>;
    shutdownAll(): Promise<void>;
    refreshRunning(): Promise<void>;
    dispose(): void;
}
export declare class ContentsManagerLess implements Contents.IManager {
    fileChanged: ISignal<Contents.IManager, Contents.IChangedArgs>;
    isDisposed: boolean;
    serverSettings: ServerConnection.ISettings;
    constructor(serverSettings: ServerConnection.ISettings);
    addDrive(drive: Contents.IDrive): void;
    localPath(path: string): string;
    normalize(path: string): string;
    resolvePath(root: string, path: string): string;
    driveName(path: string): string;
    getSharedModelFactory(path: string): Contents.ISharedFactory | null;
    get(path: string, options?: Contents.IFetchOptions | undefined): Promise<Contents.IModel>;
    getDownloadUrl(path: string): Promise<string>;
    newUntitled(options?: Contents.ICreateOptions | undefined): Promise<Contents.IModel>;
    delete(path: string): Promise<void>;
    rename(path: string, newPath: string): Promise<Contents.IModel>;
    save(path: string, options?: Partial<Contents.IModel> | undefined): Promise<Contents.IModel>;
    copy(path: string, toDir: string): Promise<Contents.IModel>;
    createCheckpoint(path: string): Promise<Contents.ICheckpointModel>;
    listCheckpoints(path: string): Promise<Contents.ICheckpointModel[]>;
    restoreCheckpoint(path: string, checkpointID: string): Promise<void>;
    deleteCheckpoint(path: string, checkpointID: string): Promise<void>;
    dispose(): void;
}
export declare class KernelManagerLess implements IKernelManager {
    runningChanged: ISignal<IKernelManager, IModel[]>;
    connectionFailure: ISignal<IKernelManager, ServerConnection.NetworkError>;
    isReady: boolean;
    ready: Promise<void>;
    serverSettings: ServerConnection.ISettings;
    isActive: boolean;
    disposed: ISignal<this, void>;
    isDisposed: boolean;
    constructor(serverSettings: ServerConnection.ISettings);
    running(): IterableIterator<IModel>;
    refreshRunning(): Promise<void>;
    startNew(createOptions?: Partial<Pick<IModel, 'name'>> | undefined, connectOptions?: Omit<IKernelConnection.IOptions, 'serverSettings' | 'model'> | undefined): Promise<IKernelConnection>;
    findById(id: string): Promise<IModel | undefined>;
    connectTo(options: IKernelConnection.IOptions): IKernelConnection;
    shutdown(id: string): Promise<void>;
    shutdownAll(): Promise<void>;
    dispose(): void;
}
export declare class KernelspecManagerLess implements IKernelspecManager {
    specsChanged: ISignal<IKernelspecManager, ISpecModels>;
    specs: ISpecModels | null;
    connectionFailure: ISignal<IManager, ServerConnection.NetworkError>;
    serverSettings: ServerConnection.ISettings;
    isReady: boolean;
    ready: Promise<void>;
    isActive: boolean;
    disposed: ISignal<this, void>;
    isDisposed: boolean;
    constructor(serverSettings: ServerConnection.ISettings);
    refreshSpecs(): Promise<void>;
    dispose(): void;
}
export declare class SessionManagerLess implements ISessionManager {
    runningChanged: ISignal<this, ISessionModel[]>;
    connectionFailure: ISignal<ISessionManager, ServerConnection.NetworkError>;
    serverSettings?: ServerConnection.ISettings | undefined;
    isReady: boolean;
    isDisposed: boolean;
    ready: Promise<void>;
    constructor(serverSettings: ServerConnection.ISettings);
    running(): IterableIterator<ISessionModel>;
    startNew(createOptions: ISessionOptions, connectOptions?: Omit<ISessionConnection.IOptions, 'serverSettings' | 'model' | 'connectToKernel'> | undefined): Promise<ISessionConnection>;
    findById(id: string): Promise<ISessionModel | undefined>;
    findByPath(path: string): Promise<ISessionModel | undefined>;
    connectTo(options: Omit<ISessionConnection.IOptions, 'serverSettings' | 'connectToKernel'>): ISessionConnection;
    shutdown(id: string): Promise<void>;
    shutdownAll(): Promise<void>;
    refreshRunning(): Promise<void>;
    stopIfNeeded(path: string): Promise<void>;
    dispose(): void;
}
export declare class BuilderManagerLess {
    serverSettings: ServerConnection.ISettings;
    constructor(serverSettings: ServerConnection.ISettings);
    get isAvailable(): boolean;
    get shouldCheck(): boolean;
    getStatus(): Promise<BuildManager.IStatus>;
    build(): Promise<void>;
    cancel(): Promise<void>;
}
export declare class SettingManagerLess extends SettingManager implements Setting.IManager {
    serverSettings: ServerConnection.ISettings;
    constructor(serverSettings: ServerConnection.ISettings);
    fetch(id: string): Promise<ISettingRegistry.IPlugin>;
    list(query?: 'ids' | undefined): Promise<{
        ids: string[];
        values: ISettingRegistry.IPlugin[];
    }>;
    save(id: string, raw: string): Promise<void>;
    remove(id: string): Promise<any>;
}
export declare class UserManagerLess implements User.IManager {
    userChanged: ISignal<this, User.IUser>;
    identity: User.IIdentity | null;
    permissions: ReadonlyJSONObject | null;
    connectionFailure: ISignal<IManager, ServerConnection.NetworkError>;
    isReady: boolean;
    ready: Promise<void>;
    isActive: boolean;
    disposed: ISignal<this, void>;
    isDisposed: boolean;
    serverSettings: ServerConnection.ISettings;
    constructor(serverSettings: ServerConnection.ISettings);
    refreshUser(): Promise<void>;
    dispose(): void;
}
export declare class EventsManagerLess implements Event.IManager {
    stream: Event.Stream;
    isDisposed: boolean;
    serverSettings: ServerConnection.ISettings;
    constructor(serverSettings: ServerConnection.ISettings);
    emit(event: Event.Request): Promise<void>;
    dispose(): void;
}
export declare class WorkspaceManagerLess extends WorkspaceManager implements Workspace.IManager {
    serverSettings: ServerConnection.ISettings;
    constructor(serverSettings: ServerConnection.ISettings);
    fetch(id: string): Promise<Workspace.IWorkspace>;
    list(): Promise<{
        ids: string[];
        values: Workspace.IWorkspace[];
    }>;
    remove(id: string): Promise<void>;
    save(id: string, workspace: Workspace.IWorkspace): Promise<void>;
}
export declare class NbConvertManagerLess {
    serverSettings: ServerConnection.ISettings;
    protected _requestingFormats: PromiseDelegate<NbConvertManager.IExportFormats> | null;
    protected _exportFormats: NbConvertManager.IExportFormats | null;
    constructor(serverSettings: ServerConnection.ISettings);
    protected fetchExportFormats(): Promise<NbConvertManager.IExportFormats>;
    protected getExportFormats(force?: boolean | undefined): Promise<NbConvertManager.IExportFormats>;
}
export declare class ServiceManagerLess implements ServiceManager.IManager {
    __NAME__: string;
    isReady: boolean;
    ready: Promise<void>;
    isDisposed: boolean;
    serverSettings: ServerConnection.ISettings;
    connectionFailure: ISignal<this, Error>;
    builder: Builder.IManager;
    contents: Contents.IManager;
    events: Event.IManager;
    sessions: ISessionManager;
    kernels: IKernelManager;
    kernelspecs: IKernelspecManager;
    settings: Setting.IManager;
    terminals: ITerminaManager;
    user: User.IManager;
    workspaces: Workspace.IManager;
    nbconvert: NbConvert.IManager;
    constructor(serverSettings?: ServerConnection.ISettings);
    dispose(): void;
    get_name: () => string;
}
export default ServiceManagerLess;
